import pathlib

from .interfaces import DestinationDecorator, Destination


class FetchFileGenerator(DestinationDecorator):
    """
    Generates a shell script which can be used to fetch all the files related to a request.
    The script uses "wget".
    """

    def __init__(self, underlying: Destination):
        super().__init__(underlying)

        # generate the file
        self.fetch_script = underlying.create_file("fetch-all.sh")

        # write some lines to it
        self.fetch_script.file().writelines([b"#!/bin/sh\n", b"\n"])

    def add_file(self, file: pathlib.Path, relative_path: str):
        super().add_file(file, relative_path)

        # add a line to the fetch script for this file
        url = self.underlying.results()["url"]
        self.fetch_script.file().writelines([f"wget {url}/{relative_path}\n".encode("utf8")])

    def close(self):
        # first close the script
        self.fetch_script.close()

        # proceed
        super().close()

    def __str__(self):
        return str(self.underlying) + " with fetch-all.sh"
