"""
Tests for ingest_envoy.launchers
"""
from unittest.mock import patch

import pytest

from ingest_envoy.launchers import IngestCalibrationLauncher

parameters = {
    "sdmId": "16B-069_sb32814386_1_001.57685.66193635417",
    "workflowName": "std_calibration",
    "spl": "uid://evla/execblock/48ba4c9d-d7c7-4a8f-9803-1115cd52459b",
    "processingStart": "2021_07_06T21_50_48",
    "destinationDir": "/lustre/aoc/cluster/pipeline/docker/workspaces/spool/tmp576dknjp",
    "workflowDir": "tmp576dknjp",
    "staging_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/staging",
    "storage_area": "/lustre/aoc/cluster/pipeline/docker/workspaces/storage",
}


class TestIngestCalibrationLauncher:
    @pytest.mark.skip("Skip until manifest builder is complete")
    @patch("ingest_envoy.ingestion_manifest.IngestionManifest.create")
    @patch("subprocess.run")
    def test_launch_ingestion(self, mock_run, mock_manifest):
        IngestCalibrationLauncher(parameters).launch_ingestion()
        assert mock_run.call_count == 2
        assert mock_manifest.call_count == 1

    @patch("subprocess.run")
    def test_run_ingest(self, mock_run):
        IngestCalibrationLauncher(parameters).run_ingest()
        assert mock_run.call_count == 1

    @pytest.mark.skip("Skip until manifest builder is complete")
    @patch("ingest_envoy.ingestion_manifest.IngestionManifest.create")
    @patch("subprocess.run")
    def test_prepare_for_ingest(self, mock_run, mock_manifest):
        IngestCalibrationLauncher(parameters).prepare_for_ingest()
        assert mock_run.call_count == 1
        assert mock_manifest.call_count == 1

    @patch("subprocess.run")
    def test_run_collection_script(self, mock_run):
        IngestCalibrationLauncher(parameters).run_collection_script()
        assert mock_run.call_count == 1

    @pytest.mark.skip("Skip until manifest builder is complete")
    @patch("ingest_envoy.ingestion_manifest.IngestionManifest.create")
    def test_create_manifest(self, mock_manifest):
        IngestCalibrationLauncher(parameters).create_manifest()
        assert mock_manifest.call_count == 1
